Hypatia
=======

.. image:: https://img.shields.io/pypi/v/hypatia.svg
        :target: https://pypi.python.org/pypi/hypatia/
        :alt: Latest Version

.. image:: https://travis-ci.org/Pylons/hypatia.png?branch=master
        :target: https://travis-ci.org/Pylons/hypatia

.. image:: https://readthedocs.org/projects/hypatia/badge/?version=latest
        :target: http://hypatia.readthedocs.org/en/latest/
        :alt: Documentation Status

A Python indexing and searching system.

See http://github.com/Pylons/hypatia for more information while this package
is in alpha development.
